==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetADLSGen1FolderDataSetPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property dataSetName The name of the dataSet.
 * @property resourceGroupName The resource group name.
 * @property shareName The name of the share.
 */
public data class GetADLSGen1FolderDataSetPlainArgs(
    public val accountName: String,
    public val dataSetName: String,
    public val resourceGroupName: String,
    public val shareName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .dataSetName(dataSetName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareName(shareName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetADLSGen1FolderDataSetPlainArgs].
 */
@PulumiTagMarker
public class GetADLSGen1FolderDataSetPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var dataSetName: String? = null

    private var resourceGroupName: String? = null

    private var shareName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("hhfnjsbvywlnxaff")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the dataSet.
     */
    @JvmName("uqoctffhhksxfahx")
    public suspend fun dataSetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataSetName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("lfaxisttgithrmot")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the share.
     */
    @JvmName("kxatpejobwhnhbnc")
    public suspend fun shareName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareName = mapped
    }

    internal fun build(): GetADLSGen1FolderDataSetPlainArgs = GetADLSGen1FolderDataSetPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        dataSetName = dataSetName ?: throw PulumiNullFieldException("dataSetName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareName = shareName ?: throw PulumiNullFieldException("shareName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/inputs/GetADLSGen1FolderDataSetPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.inputs

import com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property accountName The name of the share account.
 * @property dataSetName The name of the dataSet.
 * @property resourceGroupName The resource group name.
 * @property shareName The name of the share.
 */
public data class GetADLSGen1FolderDataSetPlainArgs(
    public val accountName: String,
    public val dataSetName: String,
    public val resourceGroupName: String,
    public val shareName: String,
) : ConvertibleToJava<com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs =
        com.pulumi.azurenative.datashare.inputs.GetADLSGen1FolderDataSetPlainArgs.builder()
            .accountName(accountName.let({ args0 -> args0 }))
            .dataSetName(dataSetName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .shareName(shareName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetADLSGen1FolderDataSetPlainArgs].
 */
@PulumiTagMarker
public class GetADLSGen1FolderDataSetPlainArgsBuilder internal constructor() {
    private var accountName: String? = null

    private var dataSetName: String? = null

    private var resourceGroupName: String? = null

    private var shareName: String? = null

    /**
     * @param value The name of the share account.
     */
    @JvmName("hxvxiusvinjfqbyl")
    public suspend fun accountName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.accountName = mapped
    }

    /**
     * @param value The name of the dataSet.
     */
    @JvmName("moqmsnypuukneesj")
    public suspend fun dataSetName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.dataSetName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("utykgaaertlennao")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the share.
     */
    @JvmName("dxigxnwdlqxmetck")
    public suspend fun shareName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.shareName = mapped
    }

    internal fun build(): GetADLSGen1FolderDataSetPlainArgs = GetADLSGen1FolderDataSetPlainArgs(
        accountName = accountName ?: throw PulumiNullFieldException("accountName"),
        dataSetName = dataSetName ?: throw PulumiNullFieldException("dataSetName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        shareName = shareName ?: throw PulumiNullFieldException("shareName"),
    )
}
